@@ -1626,6 +1626,11 @@ proc xcircuit::keyaction {keycode {keystate 0}} {
    return false
 }
 
+# Wrapper procedure to (re)bind a key to a Tcl procedure (Ed Casas 9/4/03)
+
+proc xcircuit::keybind { key proc } { bind .xcircuit.mainframe.mainarea.drawing \
+	$key "if \{!\[xcircuit::keyaction %k %s\]\} \{ $proc \}" }
+
 # Add key and button bindings for XCircuit commands (standard actions)
 # These can be overridden by binding to specific keys and/or buttons.
 
